Skip to content

An Rscript script.R command that runs in the background. This is an R6 class that extends the processx::process class.

Super class

processx::process -> rscript_process

Methods

Inherited methods


rscript_process$new()

Create a new Rscript process.

Usage

rscript_process$new(options)

Arguments

options

A list of options created via rscript_process_options().


rscript_process$cleanup()

Delete the temporary files created for this Rscript process. Only call this method if you are sure that the process is done. If you don't call this method explicitly, the temporary files will be deleted when the process object is garbage collected.

Usage

rscript_process$cleanup()


rscript_process$finalize()

Clean up after an Rscript process, remove temporary files.

Usage

rscript_process$finalize()


rscript_process$clone()

The objects of this class are cloneable with this method.

Usage

rscript_process$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Examples

if (FALSE) {
options <- rscript_process_options(script = "script.R")
rp <- rscript_process$new(options)
rp$wait()
rp$read_output_lines()
}