Skip to content

An R CMD * command that runs in the background. This is an R6 class that extends the processx::process class.

Super class

processx::process -> rcmd_process

Methods

Inherited methods


rcmd_process$new()

Start an R CMD process.

Usage

rcmd_process$new(options)

Arguments

options

A list of options created via rcmd_process_options().

Returns

A new rcmd_process object.


rcmd_process$cleanup()

Delete the temporary files created for this R CMD process. Only call this if you are sure that the process is done. If you don't call this method explicitly, the temporary files will be deleted when the process object is garbage collected.

Usage

rcmd_process$cleanup()


rcmd_process$finalize()

Clean up the temporary files created for an R CMD process.

Usage

rcmd_process$finalize()


rcmd_process$clone()

The objects of this class are cloneable with this method.

Usage

rcmd_process$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Examples

if (FALSE) {
options <- rcmd_process_options(cmd = "config", cmdargs = "CC")
rp <- rcmd_process$new(options)
rp$wait()
rp$read_output_lines()
}