| rcmd_process | R Documentation |
R CMD ProcessAn R CMD * command that runs in the background. This is an R6 class
that extends the processx::process class.
processx::process -> rcmd_process
processx::process$as_ps_handle()processx::process$format()processx::process$get_cmdline()processx::process$get_cpu_times()processx::process$get_end_time()processx::process$get_error_connection()processx::process$get_error_file()processx::process$get_exe()processx::process$get_exit_status()processx::process$get_input_connection()processx::process$get_input_file()processx::process$get_memory_info()processx::process$get_name()processx::process$get_output_connection()processx::process$get_output_file()processx::process$get_pid()processx::process$get_poll_connection()processx::process$get_result()processx::process$get_start_time()processx::process$get_status()processx::process$get_username()processx::process$get_wd()processx::process$has_error_connection()processx::process$has_input_connection()processx::process$has_output_connection()processx::process$has_poll_connection()processx::process$interrupt()processx::process$is_alive()processx::process$is_incomplete_error()processx::process$is_incomplete_output()processx::process$is_supervised()processx::process$kill()processx::process$kill_tree()processx::process$poll_io()processx::process$print()processx::process$read_all_error()processx::process$read_all_error_lines()processx::process$read_all_output()processx::process$read_all_output_lines()processx::process$read_error()processx::process$read_error_bytes()processx::process$read_error_lines()processx::process$read_output()processx::process$read_output_bytes()processx::process$read_output_lines()processx::process$resume()processx::process$signal()processx::process$supervise()processx::process$suspend()processx::process$wait()processx::process$write_input()rcmd_process$new()Start an R CMD process.
rcmd_process$new(options)
optionsA list of options created via
rcmd_process_options().
A new rcmd_process object.
rcmd_process$cleanup()Delete the temporary files created for this R CMD
process. Only call this if you are sure that the process is done.
If you don't call this method explicitly, the temporary files will
be deleted when the process object is garbage collected.
rcmd_process$cleanup()
rcmd_process$finalize()Clean up the temporary files created for an R CMD process.
rcmd_process$finalize()
rcmd_process$clone()The objects of this class are cloneable with this method.
rcmd_process$clone(deep = FALSE)
deepWhether to make a deep clone.
options <- rcmd_process_options(cmd = "config", cmdargs = "CC")
rp <- rcmd_process$new(options)
rp$wait()
rp$read_output_lines()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.